/*------------------------------------------------------*/
/* dio96.h			    			*/
/*							*/
/* Written January 1999 for NICB-DIO96 board		*/
/* 		by Tim Edwards 				*/
/*------------------------------------------------------*/

/*--------------------------------------------------------------*/
/* ioctl() commands:                                            */
/*--------------------------------------------------------------*/
/* bits: 00pp gmmc cbbb                                         */
/*--------------------------------------------------------------*/
/* p = port (0 = AP, 1 = BP, 2 = CP, 3 = DP)                    */
/* s = set/get (0 = get, 1 = set)                               */
/* m = mode (0 = bit clear (with s=1), 1 = mode,		*/
/*	     2 = byte op, 3 = bit op (get or set)		*/
/* c = channel (0 = A, 1 = B, 2 = C, 3 = (not used))            */
/* b = bit (0 to 7)                                             */
/*--------------------------------------------------------------*/

#define AP_SET_MODE	0x0a0
#define BP_SET_MODE	0x1a0
#define CP_SET_MODE	0x2a0
#define DP_SET_MODE	0x3a0

#define AP_GET_MODE	0x020
#define BP_GET_MODE	0x120
#define CP_GET_MODE	0x220
#define DP_GET_MODE	0x320

#define AP_SET_A	0x0c0
#define BP_SET_A	0x1c0
#define CP_SET_A	0x2c0
#define DP_SET_A	0x3c0

#define AP_SET_B	0x0c8
#define BP_SET_B	0x1c8
#define CP_SET_B	0x2c8
#define DP_SET_B	0x3c8

#define AP_SET_C	0x0d0
#define BP_SET_C	0x1d0
#define CP_SET_C	0x2d0
#define DP_SET_C	0x3d0

#define AP_GET_A	0x040
#define BP_GET_A	0x140
#define CP_GET_A	0x240
#define DP_GET_A	0x340

#define AP_GET_B	0x048
#define BP_GET_B	0x148
#define CP_GET_B	0x248
#define DP_GET_B	0x348

#define AP_GET_C	0x050
#define BP_GET_C	0x150
#define CP_GET_C	0x250
#define DP_GET_C	0x350

/* ioctl() bit-level calls to 82C55 pins */

#define AP_SET_A0	0x0e0
#define AP_SET_A1	0x0e1
#define AP_SET_A2	0x0e2
#define AP_SET_A3	0x0e3
#define AP_SET_A4	0x0e4
#define AP_SET_A5	0x0e5
#define AP_SET_A6	0x0e6
#define AP_SET_A7	0x0e7
#define AP_SET_B0	0x0e8
#define AP_SET_B1	0x0e9
#define AP_SET_B2	0x0ea
#define AP_SET_B3	0x0eb
#define AP_SET_B4	0x0ec
#define AP_SET_B5	0x0ed
#define AP_SET_B6	0x0ee
#define AP_SET_B7	0x0ef
#define AP_SET_C0	0x0f0
#define AP_SET_C1	0x0f1
#define AP_SET_C2	0x0f2
#define AP_SET_C3	0x0f3
#define AP_SET_C4	0x0f4
#define AP_SET_C5	0x0f5
#define AP_SET_C6	0x0f6
#define AP_SET_C7	0x0f7

#define BP_SET_A0	0x1e0
#define BP_SET_A1	0x1e1
#define BP_SET_A2	0x1e2
#define BP_SET_A3	0x1e3
#define BP_SET_A4	0x1e4
#define BP_SET_A5	0x1e5
#define BP_SET_A6	0x1e6
#define BP_SET_A7	0x1e7
#define BP_SET_B0	0x1e8
#define BP_SET_B1	0x1e9
#define BP_SET_B2	0x1ea
#define BP_SET_B3	0x1eb
#define BP_SET_B4	0x1ec
#define BP_SET_B5	0x1ed
#define BP_SET_B6	0x1ee
#define BP_SET_B7	0x1ef
#define BP_SET_C0	0x1f0
#define BP_SET_C1	0x1f1
#define BP_SET_C2	0x1f2
#define BP_SET_C3	0x1f3
#define BP_SET_C4	0x1f4
#define BP_SET_C5	0x1f5
#define BP_SET_C6	0x1f6
#define BP_SET_C7	0x1f7

#define CP_SET_A0	0x2e0
#define CP_SET_A1	0x2e1
#define CP_SET_A2	0x2e2
#define CP_SET_A3	0x2e3
#define CP_SET_A4	0x2e4
#define CP_SET_A5	0x2e5
#define CP_SET_A6	0x2e6
#define CP_SET_A7	0x2e7
#define CP_SET_B0	0x2e8
#define CP_SET_B1	0x2e9
#define CP_SET_B2	0x2ea
#define CP_SET_B3	0x2eb
#define CP_SET_B4	0x2ec
#define CP_SET_B5	0x2ed
#define CP_SET_B6	0x2ee
#define CP_SET_B7	0x2ef
#define CP_SET_C0	0x2f0
#define CP_SET_C1	0x2f1
#define CP_SET_C2	0x2f2
#define CP_SET_C3	0x2f3
#define CP_SET_C4	0x2f4
#define CP_SET_C5	0x2f5
#define CP_SET_C6	0x2f6
#define CP_SET_C7	0x2f7

#define DP_SET_A0	0x3e0
#define DP_SET_A1	0x3e1
#define DP_SET_A2	0x3e2
#define DP_SET_A3	0x3e3
#define DP_SET_A4	0x3e4
#define DP_SET_A5	0x3e5
#define DP_SET_A6	0x3e6
#define DP_SET_A7	0x3e7
#define DP_SET_B0	0x3e8
#define DP_SET_B1	0x3e9
#define DP_SET_B2	0x3ea
#define DP_SET_B3	0x3eb
#define DP_SET_B4	0x3ec
#define DP_SET_B5	0x3ed
#define DP_SET_B6	0x3ee
#define DP_SET_B7	0x3ef
#define DP_SET_C0	0x3f0
#define DP_SET_C1	0x3f1
#define DP_SET_C2	0x3f2
#define DP_SET_C3	0x3f3
#define DP_SET_C4	0x3f4
#define DP_SET_C5	0x3f5
#define DP_SET_C6	0x3f6
#define DP_SET_C7	0x3f7

#define AP_CLR_A0	0x080
#define AP_CLR_A1	0x081
#define AP_CLR_A2	0x082
#define AP_CLR_A3	0x083
#define AP_CLR_A4	0x084
#define AP_CLR_A5	0x085
#define AP_CLR_A6	0x086
#define AP_CLR_A7	0x087
#define AP_CLR_B0	0x088
#define AP_CLR_B1	0x089
#define AP_CLR_B2	0x08a
#define AP_CLR_B3	0x08b
#define AP_CLR_B4	0x08c
#define AP_CLR_B5	0x08d
#define AP_CLR_B6	0x08e
#define AP_CLR_B7	0x08f
#define AP_CLR_C0	0x090
#define AP_CLR_C1	0x091
#define AP_CLR_C2	0x092
#define AP_CLR_C3	0x093
#define AP_CLR_C4	0x094
#define AP_CLR_C5	0x095
#define AP_CLR_C6	0x096
#define AP_CLR_C7	0x097

#define BP_CLR_A0	0x180
#define BP_CLR_A1	0x181
#define BP_CLR_A2	0x182
#define BP_CLR_A3	0x183
#define BP_CLR_A4	0x184
#define BP_CLR_A5	0x185
#define BP_CLR_A6	0x186
#define BP_CLR_A7	0x187
#define BP_CLR_B0	0x188
#define BP_CLR_B1	0x189
#define BP_CLR_B2	0x18a
#define BP_CLR_B3	0x18b
#define BP_CLR_B4	0x18c
#define BP_CLR_B5	0x18d
#define BP_CLR_B6	0x18e
#define BP_CLR_B7	0x18f
#define BP_CLR_C0	0x190
#define BP_CLR_C1	0x191
#define BP_CLR_C2	0x192
#define BP_CLR_C3	0x193
#define BP_CLR_C4	0x194
#define BP_CLR_C5	0x195
#define BP_CLR_C6	0x196
#define BP_CLR_C7	0x197

#define CP_CLR_A0	0x280
#define CP_CLR_A1	0x281
#define CP_CLR_A2	0x282
#define CP_CLR_A3	0x283
#define CP_CLR_A4	0x284
#define CP_CLR_A5	0x285
#define CP_CLR_A6	0x286
#define CP_CLR_A7	0x287
#define CP_CLR_B0	0x288
#define CP_CLR_B1	0x289
#define CP_CLR_B2	0x28a
#define CP_CLR_B3	0x28b
#define CP_CLR_B4	0x28c
#define CP_CLR_B5	0x28d
#define CP_CLR_B6	0x28e
#define CP_CLR_B7	0x28f
#define CP_CLR_C0	0x290
#define CP_CLR_C1	0x291
#define CP_CLR_C2	0x292
#define CP_CLR_C3	0x293
#define CP_CLR_C4	0x294
#define CP_CLR_C5	0x295
#define CP_CLR_C6	0x296
#define CP_CLR_C7	0x297

#define DP_CLR_A0	0x380
#define DP_CLR_A1	0x381
#define DP_CLR_A2	0x382
#define DP_CLR_A3	0x383
#define DP_CLR_A4	0x384
#define DP_CLR_A5	0x385
#define DP_CLR_A6	0x386
#define DP_CLR_A7	0x387
#define DP_CLR_B0	0x388
#define DP_CLR_B1	0x389
#define DP_CLR_B2	0x38a
#define DP_CLR_B3	0x38b
#define DP_CLR_B4	0x38c
#define DP_CLR_B5	0x38d
#define DP_CLR_B6	0x38e
#define DP_CLR_B7	0x38f
#define DP_CLR_C0	0x390
#define DP_CLR_C1	0x391
#define DP_CLR_C2	0x392
#define DP_CLR_C3	0x393
#define DP_CLR_C4	0x394
#define DP_CLR_C5	0x395
#define DP_CLR_C6	0x396

#define AP_GET_A0	0x060
#define AP_GET_A1	0x061
#define AP_GET_A2	0x062
#define AP_GET_A3	0x063
#define AP_GET_A4	0x064
#define AP_GET_A5	0x065
#define AP_GET_A6	0x066
#define AP_GET_A7	0x067
#define AP_GET_B0	0x068
#define AP_GET_B1	0x069
#define AP_GET_B2	0x06a
#define AP_GET_B3	0x06b
#define AP_GET_B4	0x06c
#define AP_GET_B5	0x06d
#define AP_GET_B6	0x06e
#define AP_GET_B7	0x06f
#define AP_GET_C0	0x070
#define AP_GET_C1	0x071
#define AP_GET_C2	0x072
#define AP_GET_C3	0x073
#define AP_GET_C4	0x074
#define AP_GET_C5	0x075
#define AP_GET_C6	0x076
#define AP_GET_C7	0x077

#define BP_GET_A0	0x160
#define BP_GET_A1	0x161
#define BP_GET_A2	0x162
#define BP_GET_A3	0x163
#define BP_GET_A4	0x164
#define BP_GET_A5	0x165
#define BP_GET_A6	0x166
#define BP_GET_A7	0x167
#define BP_GET_B0	0x168
#define BP_GET_B1	0x169
#define BP_GET_B2	0x16a
#define BP_GET_B3	0x16b
#define BP_GET_B4	0x16c
#define BP_GET_B5	0x16d
#define BP_GET_B6	0x16e
#define BP_GET_B7	0x16f
#define BP_GET_C0	0x170
#define BP_GET_C1	0x171
#define BP_GET_C2	0x172
#define BP_GET_C3	0x173
#define BP_GET_C4	0x174
#define BP_GET_C5	0x175
#define BP_GET_C6	0x176
#define BP_GET_C7	0x177

#define CP_GET_A0	0x260
#define CP_GET_A1	0x261
#define CP_GET_A2	0x262
#define CP_GET_A3	0x263
#define CP_GET_A4	0x264
#define CP_GET_A5	0x265
#define CP_GET_A6	0x266
#define CP_GET_A7	0x267
#define CP_GET_B0	0x268
#define CP_GET_B1	0x269
#define CP_GET_B2	0x26a
#define CP_GET_B3	0x26b
#define CP_GET_B4	0x26c
#define CP_GET_B5	0x26d
#define CP_GET_B6	0x26e
#define CP_GET_B7	0x26f
#define CP_GET_C0	0x270
#define CP_GET_C1	0x271
#define CP_GET_C2	0x272
#define CP_GET_C3	0x273
#define CP_GET_C4	0x274
#define CP_GET_C5	0x275
#define CP_GET_C6	0x276
#define CP_GET_C7	0x277

#define DP_GET_A0	0x360
#define DP_GET_A1	0x361
#define DP_GET_A2	0x362
#define DP_GET_A3	0x363
#define DP_GET_A4	0x364
#define DP_GET_A5	0x365
#define DP_GET_A6	0x366
#define DP_GET_A7	0x367
#define DP_GET_B0	0x368
#define DP_GET_B1	0x369
#define DP_GET_B2	0x36a
#define DP_GET_B3	0x36b
#define DP_GET_B4	0x36c
#define DP_GET_B5	0x36d
#define DP_GET_B6	0x36e
#define DP_GET_B7	0x36f
#define DP_GET_C0	0x370
#define DP_GET_C1	0x371
#define DP_GET_C2	0x372
#define DP_GET_C3	0x373
#define DP_GET_C4	0x374
#define DP_GET_C5	0x375
#define DP_GET_C6	0x376
#define DP_GET_C7	0x377

/*---------------------------------------------------------------*/
/* Control Register values for use with DIO_SET_MODE ioctl call. */
/*---------------------------------------------------------------*/

#define OUTPUT		0x0

/* input modes */

#define CNTL_A		0x10
#define CNTL_B		0x02
#define CNTL_CL		0x01
#define CNTL_CH		0x08
#define CNTL_C		0x09	/* CNTL_C = CNTL_CL | CNTL_CH */
#define MODE_SET	0x80	/* set by driver---shouldn't be needed */

/*--------------------------------------------------------------*/
/* 82C55 modes 							*/
/* GRPA controls mode of ports A and CU 			*/
/* GRPB controls mode of ports B and CL 			*/
/* Default setting on opening the device is Mode 0 (Normal I/O) */
/*      for both groups 					*/
/*--------------------------------------------------------------*/

#define GRPA_MODE0 0x0		/* Normal I/O 		*/
#define GRPA_MODE1 0x20		/* Strobed I/O 		*/
#define GRPA_MODE2 0x40		/* Bi-directional Bus 	*/
#define GRPB_MODE0 0x0		/* Normal I/O 		*/
#define GRPB_MODE1 0x04		/* Strobed I/O		*/

/*--------------------------------------------------------------*/
/* Mode 1 bit definitions (port C only)				*/
/*--------------------------------------------------------------*/

#define OBFA		0x80
#define INTE1		0x40
#define IBFA		0x20
#define INTE2		0x10
#define INTRA		0x8
#define INTEB		0x4
#define IBFB		0x2
#define INTRB		0x1

/*--------------------------------------------------------------*/
/* 82C54 timer/counter modes and interrupt control		*/
/*--------------------------------------------------------------*/

#define COUNTER0   	0x0		/* Access counter 0 */
#define COUNTER1   	0x40		/* Access counter 1 */
#define ACCESS_LSB 	0x10
#define ACCESS_MSB 	0x20
#define ACCESS_BOTH	0x30
#define LATCH_COUNTER	0x0
#define CNTR_BCD	0x01
#define CNTR_BINARY	0x0
#define CNTR_MODE0	0x0
#define CNTR_MODE1	0x2
#define CNTR_MODE2	0x4
#define CNTR_MODE3	0x6
#define AIRQ0		0x0
#define AIRQ1		0x2
#define BIRQ0		0x4
#define BIRQ1		0x8
#define CIRQ0		0x10
#define CIRQ1		0x20
#define DIRQ0		0x40
#define DIRQ1		0x80
#define INTEN		0x4
#define CTRIRQ		0x2
#define CTR1		0x1

/*--------------------------------------------------------------*/
