/*
 * Copyright (C) 1995  Sam Moore, Warren Jasper
 * All rights reserved.
 * Modified by Tim Edwards, April, 1997 for CIO-DIO48 board
 *
 * This software may be freely copied, modified, and redistributed
 * provided that this copyright notice is preserved on all copies.
 *
 * You may not distribute this software, in whole or in part, as part of
 * any commercial product without the express consent of the authors.
 *
 * There is no warranty or other guarantee of fitness of this software
 * for any purpose.  It is provided solely "as is".
 *
 */

/***************************************************************************
 *
 *  diotest.c
 *
 *  This program is used to test the CIO-DIO48
 *  Linux loadable module (dio48).
 *
 ***************************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <sys/types.h>
#include <fcntl.h>
#include <unistd.h>
#include <sys/ioctl.h>
#include <linux/dio96.h>

/***************************************************************************
 *
 *  Global Data
 *
 ***************************************************************************/

#define LONG unsigned long
#define BYTE unsigned char

char *Dev0Name = "/dev/dio/dio0";
char *Dev1Name = "/dev/dio/dio1";

/***************************************************************************
 *
 *  Main
 *
 ***************************************************************************/

int main(int argc, char **argv)
{
  int	fd0, fd1;
  long  dataval;
  int   rval;

  /* Open the device file for the counter */

  if ((fd0 = open(Dev0Name, O_RDWR)) < 0) {
    printf("error opening DIO96 device AP\n");
    exit(2);
  }
  printf("Setting mode of 82C55-A to all ports output.\n");
  ioctl(fd0, AP_SET_MODE, OUTPUT);

  if ((fd1 = open(Dev1Name, O_RDWR)) < 0) {
    printf("error opening DIO96 device BP\n");
    exit(2);
  }
  printf("Setting mode of 82C55-B to all ports output.\n");
  ioctl(fd1, BP_SET_MODE, OUTPUT);

  printf("sleep before read\n");
  sleep(1);
  

    dataval = (LONG)0xffffff;
    if (write(fd0, &dataval, 3) != 3 ) {
      printf("main() in test.c: error on write.\n");
      exit(1);
    }
    if ((rval = read(fd0, &dataval, 3)) != 3 ) {
      printf("main() in test.c: error on readback.\n");
      printf("   read() returned %d, expected 3\n", rval); 
      printf("   buffer contains %0lx, expected 0xffffff\n", dataval);
      exit(1);
    }
    else printf("Data expected: 0xffffff, Data read: %0lx\n", dataval);
    sleep(1);
    dataval = (LONG)0x00;
    if (write(fd0, &dataval, 3) != 3 ) {
      printf("main() in test.c: error on write.\n");
      exit(1);
    }
    if (read(fd0, &dataval, 3) != 3 ) {
      printf("main() in test.c: error on readback.\n");
      exit(1);
    }
    else printf("Data expected: 0x000000, Data read: %0lx\n", dataval);
    sleep(1);
    ioctl(fd0, AP_SET_A, (BYTE)0xaa);
    ioctl(fd0, AP_GET_A, &dataval);
    printf("Read on A expected: 0xaa, Data read: %0lx\n", dataval);
    ioctl(fd0, AP_SET_B, (BYTE)0x55);
    ioctl(fd0, AP_GET_B, &dataval);
    printf("Read on B expected: 0x55, Data read: %0lx\n", dataval);
    ioctl(fd0, AP_SET_C, (BYTE)0xc3);
    ioctl(fd0, AP_GET_C, &dataval);
    printf("Read on C expected: 0xc3, Data read: %0lx\n", dataval);
    sleep(1);

    /* Again for device fd1 */

    dataval = (LONG)0xffffff;
    if (write(fd1, &dataval, 3) != 3 ) {
      printf("main() in test.c: error on write.\n");
      exit(1);
    }
    if ((rval = read(fd1, &dataval, 3)) != 3 ) {
      printf("main() in test.c: error on readback.\n");
      printf("   read() returned %d, expected 3\n", rval); 
      printf("   buffer contains %0lx, expected 0xffffff\n", dataval);
      exit(1);
    }
    else printf("Data expected: 0xffffff, Data read: %0lx\n", dataval);
    sleep(1);
    dataval = (LONG)0x00;
    if (write(fd1, &dataval, 3) != 3 ) {
      printf("main() in test.c: error on write.\n");
      exit(1);
    }
    if (read(fd1, &dataval, 3) != 3 ) {
      printf("main() in test.c: error on readback.\n");
      exit(1);
    }
    else printf("Data expected: 0x000000, Data read: %0lx\n", dataval);
    sleep(1);
    ioctl(fd1, BP_SET_A, (BYTE)0xaa);
    ioctl(fd1, BP_GET_A, &dataval);
    printf("Read on A expected: 0xaa, Data read: %0lx\n", dataval);
    ioctl(fd1, BP_SET_B, (BYTE)0x55);
    ioctl(fd1, BP_GET_B, &dataval);
    printf("Read on B expected: 0x55, Data read: %0lx\n", dataval);
    ioctl(fd1, BP_SET_C, (BYTE)0xc3);
    ioctl(fd1, BP_GET_C, &dataval);
    printf("Read on C expected: 0xc3, Data read: %0lx\n", dataval);
    sleep(1);

  close(fd0);
  close(fd1);
  return 0;
}
	
